@@ -6,16 +6,6 @@ from .finite_element import FiniteElement as _FiniteElement
 
 _folder = _os.path.dirname(_os.path.realpath(__file__))
 
-if _os.path.isfile(_os.path.join(_folder, "../VERSION")):
-    # If running from folder
-    _v_folder = _os.path.join(_folder, "..")
-else:
-    # If running from installation
-    _v_folder = _folder
-
-with open(_os.path.join(_v_folder, "VERSION")) as _f:
-    version = _f.read().strip()
-
 _elementmap = {}
 _elementlist = []
 
@@ -75,11 +65,15 @@ def create_reference(cell_type, vertices=None):
         The reference cell type.
 
         Supported values:
-        interval, triangle, quadrilateral, tetrahedron, hexahedron,
+        point, interval, triangle, quadrilateral, tetrahedron, hexahedron,
         prism, pyramid, dual polygon(number_of_triangles)
     vertices : list
         The vertices of the reference.
     """
+    if cell_type == "point":
+        if vertices is not None:
+            return _references.Point(vertices)
+        return _references.Point()
     if cell_type == "interval":
         if vertices is not None:
             return _references.Interval(vertices)
@@ -126,7 +120,7 @@ def create_element(cell_type, element_type, order, variant="equispaced"):
         The reference cell type.
 
         Supported values:
-        interval, triangle, quadrilateral, tetrahedron, hexahedron,
+        point, interval, triangle, quadrilateral, tetrahedron, hexahedron,
         prism, pyramid, dual polygon(number_of_triangles)
     element_type : str
         The type of the element.
@@ -139,6 +133,7 @@ def create_element(cell_type, element_type, order, variant="equispaced"):
         matrix discontinuous Lagrange,
         symmetric matrix discontinuous Lagrange,
         Crouzeix-Raviart, CR, Crouzeix-Falk, CF,
+        conforming Crouzeix-Raviart, conforming CR,
         serendipity, S,
         serendipity Hcurl, Scurl, BDMCE, AAE,
         serendipity Hdiv, Sdiv, BDMCF, AAF,
