@@ -7,7 +7,7 @@ This element's definition appears in https://doi.org/10.1051/m2an/1987210405811
 from ..finite_element import CiarletElement
 from ..moments import make_integral_moment_dofs
 from ..polynomials import polynomial_set
-from ..symbolic import x, zero
+from ..symbolic import x
 from ..functionals import NormalIntegralMoment, IntegralMoment
 from .lagrange import DiscontinuousLagrange, VectorDiscontinuousLagrange
 
@@ -19,9 +19,9 @@ def bdfm_polyset(reference, order):
     if reference.name == "quadrilateral":
         for i in polynomial_set(dim, 1, order):
             if i != x[0] ** order:
-                pset.append((zero, i))
+                pset.append((0, i))
             if i != x[1] ** order:
-                pset.append((i, zero))
+                pset.append((i, 0))
     elif reference.name == "triangle":
         pset = polynomial_set(dim, dim, order - 1)
         for i in range(order):
@@ -32,9 +32,9 @@ def bdfm_polyset(reference, order):
         for i in range(1, order + 1):
             for j in range(order + 1 - i):
                 k = order - i - j
-                pset.append((x[0] ** i * x[1] ** j * x[2] ** k, zero, zero))
-                pset.append((zero, x[1] ** i * x[0] ** j * x[2] ** k, zero))
-                pset.append((zero, zero, x[2] ** i * x[0] ** j * x[1] ** k))
+                pset.append((x[0] ** i * x[1] ** j * x[2] ** k, 0, 0))
+                pset.append((0, x[1] ** i * x[0] ** j * x[2] ** k, 0))
+                pset.append((0, 0, x[2] ** i * x[0] ** j * x[1] ** k))
     elif reference.name == "tetrahedron":
         pset = polynomial_set(dim, dim, order - 1)
         for i in range(order):
