@@ -1,5 +1,5 @@
 import sympy
-from utils import all_symequal
+from .utils import all_symequal
 from symfem import create_element
 from symfem.symbolic import x
 
