@@ -5,7 +5,9 @@ from symfem import create_element
 from symfem.finite_element import CiarletElement, DirectElement
 from symfem.symbolic import subs, x, PiecewiseFunction
 from symfem.vectors import vsub
-from utils import test_elements, all_symequal
+from symfem.symbolic import to_sympy
+from symfem.calculus import diff
+from .utils import test_elements, all_symequal
 
 
 def test_all_tested():
@@ -149,7 +151,7 @@ def test_element_functionals_and_continuity(
         vertices = ((-1, ), (0, ))
         entity_pairs = [[0, (0, 1)]]
     elif cell_type == "triangle":
-        vertices = ((-1, 2), (0, 0), (0, 1))
+        vertices = ((-1, 0), (0, 0), (0, 1))
         entity_pairs = [[0, (0, 1)], [0, (2, 2)], [1, (1, 0)]]
     elif cell_type == "tetrahedron":
         vertices = ((-1, 0, 0), (0, 0, 0), (0, 1, 0), (0, 0, 1))
@@ -188,13 +190,6 @@ def test_element_functionals_and_continuity(
                 basis2 = space.map_to_cell(vertices)
             except NotImplementedError:
                 pytest.xfail("Mapping not implemented for this element yet")
-            if space.names[0] == "Bernardi-Raugel":
-                # TODO: remove this hack
-                if space.reference.name == "triangle":
-                    basis2[4], basis2[5] = basis2[5], basis2[4]
-                if space.reference.name == "tetrahedron":
-                    basis2[6], basis2[7] = basis2[7], basis2[6]
-                    basis2[9], basis2[10] = basis2[10], basis2[9]
 
             f = basis[fi]
             g = basis2[gi]
@@ -214,9 +209,9 @@ def test_element_functionals_and_continuity(
                 f = [f]
                 g = [g]
                 for _ in range(order):
-                    deriv_f = [d.diff(i) for d in deriv_f for i in x[:space.reference.tdim]]
+                    deriv_f = [diff(d, i) for d in deriv_f for i in x[:space.reference.tdim]]
                     f += deriv_f
-                    deriv_g = [d.diff(i) for d in deriv_g for i in x[:space.reference.tdim]]
+                    deriv_g = [diff(d, i) for d in deriv_g for i in x[:space.reference.tdim]]
                     g += deriv_g
             elif space.continuity == "H(div)":
                 f = f[0]
@@ -248,8 +243,8 @@ def test_element_functionals_and_continuity(
                 f = f[0]
                 g = g[0]
             elif space.continuity == "integral inner H(div)":
-                f = f[0].integrate((x[1], 0, 1))
-                g = g[0].integrate((x[1], 0, 1))
+                f = f[0].integrate((to_sympy(x[1]), 0, 1))
+                g = g[0].integrate((to_sympy(x[1]), 0, 1))
             else:
                 raise ValueError(f"Unknown continuity: {space.continuity}")
 
